# eis-process-manager
The EMIL Process Manager API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.process-manager
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import eis.process-manager
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.process-manager
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.process-manager
from pprint import pprint
from eis.process-manager.api import decision_table_versions_api
from eis.process-manager.model.get_decision_table_version_response_class import GetDecisionTableVersionResponseClass
from eis.process-manager.model.list_decision_table_versions_response_class import ListDecisionTableVersionsResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.process-manager.Configuration(
    host = "https://apiv2.emil.de"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Bearer is automatically handled with exported environment variables. However, you
# can manuallay configure Bearer authorization (JWT): bearer
configuration = eis.process-manager.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# After manual token becomes invalid, the SDK will default to re-login automatically
# with environment variable credentials.


# Enter a context with an instance of the API client
with eis.process-manager.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = decision_table_versions_api.DecisionTableVersionsApi(api_client)
    decision_table_code = "decisionTableCode_example" # str | Unique identifier for the object.
    version = "version_example" # str | The version number of the entity
    authorization = "Authorization_example" # str | Bearer Token: provided by the login endpoint under the name accessToken. (optional)

    try:
        # Retrieve the decision table version
        api_response = api_instance.get_decision_table_version(decision_table_code, version, authorization=authorization)
        pprint(api_response)
    except eis.process-manager.ApiException as e:
        print("Exception when calling DecisionTableVersionsApi->get_decision_table_version: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DecisionTableVersionsApi* | [**get_decision_table_version**](docs/DecisionTableVersionsApi.md#get_decision_table_version) | **GET** /processmanager/v1/decision-tables/{decisionTableCode}/versions/{version} | Retrieve the decision table version
*DecisionTableVersionsApi* | [**list_decision_table_versions**](docs/DecisionTableVersionsApi.md#list_decision_table_versions) | **GET** /processmanager/v1/decision-tables/{decisionTableCode}/versions | List decision table versions
*DecisionTablesApi* | [**create_decision_table**](docs/DecisionTablesApi.md#create_decision_table) | **POST** /processmanager/v1/decision-tables | Create the decision table
*DecisionTablesApi* | [**get_decision_table**](docs/DecisionTablesApi.md#get_decision_table) | **GET** /processmanager/v1/decision-tables/{code} | Retrieve the decision table
*DecisionTablesApi* | [**list_decision_tables**](docs/DecisionTablesApi.md#list_decision_tables) | **GET** /processmanager/v1/decision-tables | List decision tables
*DecisionTablesApi* | [**patch_workflow**](docs/DecisionTablesApi.md#patch_workflow) | **PATCH** /processmanager/v1/decision-tables/{code} | Patch the decision table
*DecisionTablesApi* | [**update_decision_table**](docs/DecisionTablesApi.md#update_decision_table) | **PUT** /processmanager/v1/decision-tables/{code} | Update the decision table
*ServiceEventApi* | [**define_service_event**](docs/ServiceEventApi.md#define_service_event) | **POST** /processmanager/v1/service-event/define | 
*WorkflowInstancesApi* | [**archive_workflow_instance_variables**](docs/WorkflowInstancesApi.md#archive_workflow_instance_variables) | **POST** /processmanager/v1/workflow-instances/{code}/archive-variables | Create the archive workflow instance variables
*WorkflowInstancesApi* | [**cancel_instance**](docs/WorkflowInstancesApi.md#cancel_instance) | **POST** /processmanager/v1/workflow-instances/{code}/cancel | 
*WorkflowInstancesApi* | [**get_workflow_instance**](docs/WorkflowInstancesApi.md#get_workflow_instance) | **GET** /processmanager/v1/workflow-instances/{code} | 
*WorkflowInstancesApi* | [**get_workflow_instance_variables**](docs/WorkflowInstancesApi.md#get_workflow_instance_variables) | **GET** /processmanager/v1/workflow-instances/{code}/variables/{taskKey} | Retrieve the workflow instance variables
*WorkflowInstancesApi* | [**list_workflow_instances**](docs/WorkflowInstancesApi.md#list_workflow_instances) | **GET** /processmanager/v1/workflow-instances | List workflow instances
*WorkflowInstancesApi* | [**retry_instance**](docs/WorkflowInstancesApi.md#retry_instance) | **POST** /processmanager/v1/workflow-instances/{code}/retry | 
*WorkflowVersionsApi* | [**get_workflow_version**](docs/WorkflowVersionsApi.md#get_workflow_version) | **GET** /processmanager/v1/workflow_versions/{code} | 
*WorkflowVersionsApi* | [**list_workflow_versions**](docs/WorkflowVersionsApi.md#list_workflow_versions) | **GET** /processmanager/v1/workflow_versions | 
*WorkflowsApi* | [**create_workflow**](docs/WorkflowsApi.md#create_workflow) | **POST** /processmanager/v1/workflows | 
*WorkflowsApi* | [**get_workflow**](docs/WorkflowsApi.md#get_workflow) | **GET** /processmanager/v1/workflows/{code} | 
*WorkflowsApi* | [**list_workflows**](docs/WorkflowsApi.md#list_workflows) | **GET** /processmanager/v1/workflows | 
*WorkflowsApi* | [**trigger_workflow**](docs/WorkflowsApi.md#trigger_workflow) | **POST** /processmanager/v1/workflows/{code}/trigger | 
*WorkflowsApi* | [**trigger_workflow_sync**](docs/WorkflowsApi.md#trigger_workflow_sync) | **POST** /processmanager/v1/workflows/{code}/trigger-sync | 
*DefaultApi* | [**check**](docs/DefaultApi.md#check) | **GET** /processmanager/health | Health Check


## Documentation For Models

 - [CreateDecisionTableResponseClass](docs/CreateDecisionTableResponseClass.md)
 - [CreateWorkflowRequestDto](docs/CreateWorkflowRequestDto.md)
 - [DecisionTableClass](docs/DecisionTableClass.md)
 - [DecisionTableVersionClass](docs/DecisionTableVersionClass.md)
 - [DecisionTableVersionClassWithoutDefinition](docs/DecisionTableVersionClassWithoutDefinition.md)
 - [DefineServiceEventRequestDto](docs/DefineServiceEventRequestDto.md)
 - [GetDecisionTableResponseClass](docs/GetDecisionTableResponseClass.md)
 - [GetDecisionTableVersionResponseClass](docs/GetDecisionTableVersionResponseClass.md)
 - [GetWorkflowInstanceRequestDto](docs/GetWorkflowInstanceRequestDto.md)
 - [GetWorkflowInstanceResponseClass](docs/GetWorkflowInstanceResponseClass.md)
 - [GetWorkflowInstanceVariablesClass](docs/GetWorkflowInstanceVariablesClass.md)
 - [GetWorkflowRequestDto](docs/GetWorkflowRequestDto.md)
 - [GetWorkflowResponseClass](docs/GetWorkflowResponseClass.md)
 - [GetWorkflowVersionResponseClass](docs/GetWorkflowVersionResponseClass.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [ListDecisionTableVersionsResponseClass](docs/ListDecisionTableVersionsResponseClass.md)
 - [ListDecisionTablesResponseClass](docs/ListDecisionTablesResponseClass.md)
 - [ListWorkflowInstancesResponseClass](docs/ListWorkflowInstancesResponseClass.md)
 - [ListWorkflowVersionsResponseClass](docs/ListWorkflowVersionsResponseClass.md)
 - [ListWorkflowsResponseClass](docs/ListWorkflowsResponseClass.md)
 - [PatchDecisionTableResponseClass](docs/PatchDecisionTableResponseClass.md)
 - [PatchWorkflowRequestDto](docs/PatchWorkflowRequestDto.md)
 - [TriggerWorkflowRequestDto](docs/TriggerWorkflowRequestDto.md)
 - [TriggerWorkflowRequestGrpcDto](docs/TriggerWorkflowRequestGrpcDto.md)
 - [TriggerWorkflowWithResultResponseClass](docs/TriggerWorkflowWithResultResponseClass.md)
 - [UpdateDecisionTableResponseClass](docs/UpdateDecisionTableResponseClass.md)
 - [UpdateWorkflowRequestDto](docs/UpdateWorkflowRequestDto.md)
 - [WorkflowClass](docs/WorkflowClass.md)
 - [WorkflowEventClass](docs/WorkflowEventClass.md)
 - [WorkflowInstanceClass](docs/WorkflowInstanceClass.md)
 - [WorkflowInstanceCodeRequestDto](docs/WorkflowInstanceCodeRequestDto.md)
 - [WorkflowInstanceVariablesClass](docs/WorkflowInstanceVariablesClass.md)
 - [WorkflowVersionClass](docs/WorkflowVersionClass.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.process-manager.apis and eis.process-manager.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.process-manager.api.default_api import DefaultApi`
- `from eis.process-manager.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.process-manager
from eis.process-manager.apis import *
from eis.process-manager.models import *
```

